@@ -14,7 +14,7 @@ from sys import stdout
 import mysql.connector
 import six
 from mysql.connector import errorcode
-from tqdm import trange
+from tqdm import tqdm, trange
 
 from mysql_to_sqlite3.sqlite_utils import (
     adapt_decimal,
@@ -66,6 +66,8 @@ class MySQLtoSQLite:
 
         self._mysql_port = int(kwargs.get("mysql_port") or 3306)
 
+        self._mysql_ssl_disabled = kwargs.get("mysql_ssl_disabled") or False
+
         self._current_chunk_number = 0
         self._chunk_size = int(kwargs.get("chunk")) if kwargs.get("chunk") else None
 
@@ -99,6 +101,7 @@ class MySQLtoSQLite:
                 password=self._mysql_password,
                 host=self._mysql_host,
                 port=self._mysql_port,
+                ssl_disabled=self._mysql_ssl_disabled,
             )
             if not self._mysql.is_connected():
                 raise ConnectionError("Unable to connect to MySQL")
@@ -166,6 +169,10 @@ class MySQLtoSQLite:
             raise ValueError("Invalid column_type!")
 
         data_type = match.group(0).upper()
+
+        if data_type.endswith(" UNSIGNED"):
+            data_type = data_type.replace(" UNSIGNED", "")
+
         if data_type in {
             "BIGINT",
             "BLOB",
@@ -352,7 +359,11 @@ class MySQLtoSQLite:
                             encode_data_for_sqlite(col) if col is not None else None
                             for col in row
                         )
-                        for row in self._mysql_cur.fetchall()
+                        for row in tqdm(
+                            self._mysql_cur.fetchall(),
+                            total=total_records,
+                            disable=self._quiet,
+                        )
                     ),
                 )
             self._sqlite.commit()
